@@ -28,6 +28,9 @@
 #include "networkstatus.h"
 
 #include "appletproxymodel.h"
+#include "creatableconnectionsmodel.h"
+#include "editorproxymodel.h"
+#include "kcmidentitymodel.h"
 #include "networkmodel.h"
 
 #include "handler.h"
@@ -51,4 +54,10 @@ void QmlPlugins::registerTypes(const char* uri)
     qmlRegisterType<NetworkModel>(uri, 0, 2, "NetworkModel");
     // @uri org.kde.plasma.networkmanagement.AppletProxyModel
     qmlRegisterType<AppletProxyModel>(uri, 0, 2, "AppletProxyModel");
+    // @uri org.kde.plasma.networkmanagement.EditorProxyModel
+    qmlRegisterType<EditorProxyModel>(uri, 0, 2, "EditorProxyModel");
+    // @uri org.kde.plasma.networkmanagement.KcmIdentityModel
+    qmlRegisterType<KcmIdentityModel>(uri, 0, 2, "KcmIdentityModel");
+    // @uri org.kde.plasma.networkmanagement.CreatableConnectionsModel
+    qmlRegisterType<CreatableConnectionsModel>(uri, 0, 2, "CreatableConnectionsModel");
 }
